Learn R Programming

Z10 (version 0.1.0)

daily.precip.totals: Return daily precipitation totals for a site

Description

This function calculates the daily precipitation totals over the specified date range

Usage

daily.precip.totals(site, bgn.date, end.date)

Arguments

site

Parameter of class character. The NEON site data should be downloaded for.

bgn.date

Optional. The start date of the period to generate statistics for. If not supplied, the first date of NEON data will be used.

end.date

Optional. The end date of the period to generate statistics for. If not supplied, the last date of NEON data will be used.

Value

A data frame of primary and secondary precipitation totals by date. Totals are in millimeters.

See Also

Currently none

Examples

Run this code
# NOT RUN {
# Return the entire period of record at CPER
cper=Z10::daily.precip.totals(site = "CPER")
# }

Run the code above in your browser using DataLab