Learn R Programming

Z10 (version 0.1.0)

daily.rad.stats: Return daily total radiation statistics for a site

Description

This function calculates the daily daylight mean and maximum total solar radiation values for a site over the specified date range.

Usage

daily.rad.stats(site, bgn.date, end.date)

Arguments

site

Parameter of class character. The NEON site data should be downloaded for.

bgn.date

Optional. The start date of the period to generate statistics for. If not supplied, the first date of NEON data will be used.

end.date

Optional. The end date of the period to generate statistics for. If not supplied, the last date of NEON data will be used.

Value

Mean and maximum daylight total solar radiation values by date, in watts per meter squared.

See Also

Currently none

Examples

Run this code
# NOT RUN {
# Return radiaiton stats for CPER over the summer solstice
cper=Z10::daily.rad.stats(site = "CPER")
# More information on the radiation data product used:
Z10::get.dp.meta("DP1.00014.001")$product.abstract
# }

Run the code above in your browser using DataLab