daily.soil.temp.mean: Return daily soil temperature means by horizon
Description
This function calculates the daily miniumum, mean, and maximum
temperature values for a site over its period of record for soil sensors located
in plot 1 of the site, at the lowest available instrument in each soil horizon.
Usage
daily.soil.temp.mean(site, bgn.date, end.date)
Arguments
site
Parameter of class character.
The NEON site data should be downloaded for.
bgn.date
Optional. The start date of the period to generate statistics for.
If not supplied, the first date of NEON data will be used.
end.date
Optional. The end date of the period to generate statistics for.
If not supplied, the last date of NEON data will be used.
Value
A mean daily soil temperatures, by soil horizon, in degrees centigrade.