powered by
This function calculates the daily miniumum, mean, and maximum temperature values for a site over its period of record.
daily.temp.stats(site, bgn.date, end.date)
Parameter of class character. The NEON site data should be downloaded for.
Optional. The start date of the period to generate statistics for. If not supplied, the first date of NEON data will be used.
Optional. The end date of the period to generate statistics for. If not supplied, the last date of NEON data will be used.
A list of min, mean and max temperature values at the site, in centigrade
Currently none
# NOT RUN { cper=Z10::daily.temp.stats(site = "CPER") # }
Run the code above in your browser using DataLab