Learn R Programming

Z10 (version 0.1.0)

site.litter.isotopes: Return Mean Delta Values of Stable Isotopes in Litterfall

Description

This function calculates the mean delta values for nitrogen-15 and carbon-13 isotopes over the period of record at a site.

Usage

site.litter.isotopes(site)

Arguments

site

Parameter of class character. The NEON site data should be downloaded for.

Value

A list of min, mean and max net solar radiation values at the site, in watts per meter squared

See Also

Currently none

Examples

Run this code
# NOT RUN {
cper=Z10::site.litter.isotopes(site = "SCBI")
# }

Run the code above in your browser using DataLab