powered by
This function calculates the daily precipitation totals over the specified date range
daily.precip.totals(site, bgn.date, end.date)
Parameter of class character. The NEON site data should be downloaded for.
Optional. The start date of the period to generate statistics for. If not supplied, the first date of NEON data will be used.
Optional. The end date of the period to generate statistics for. If not supplied, the last date of NEON data will be used.
A data frame of primary and secondary precipitation totals by date. Totals are in millimeters.
Currently none
# NOT RUN { # Return the entire period of record at CPER cper=Z10::daily.precip.totals(site = "CPER") # }
Run the code above in your browser using DataLab