powered by
This function calculates the mean delta values for nitrogen-15 and carbon-13 isotopes over the period of record at a site.
site.litter.isotopes(site)
Parameter of class character. The NEON site data should be downloaded for.
A list of min, mean and max net solar radiation values at the site, in watts per meter squared
Currently none
# NOT RUN { cper=Z10::site.litter.isotopes(site = "SCBI") # }
Run the code above in your browser using DataLab